"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var prosemirror_utils_1 = require("prosemirror-utils");
var media_client_1 = require("@atlaskit/media-client");
var editor_common_1 = require("@atlaskit/editor-common");
var styled_1 = require("./styled");
var Resizer_1 = tslib_1.__importDefault(require("./Resizer"));
var utils_1 = require("./utils");
var media_single_1 = require("../../utils/media-single");
var ResizableMediaSingle = /** @class */ (function (_super) {
    tslib_1.__extends(ResizableMediaSingle, _super);
    function ResizableMediaSingle() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            offsetLeft: _this.calcOffsetLeft(),
            // We default to true until we resolve the file type
            isVideoFile: true,
        };
        _this.calcNewSize = function (newWidth, stop) {
            var layout = _this.props.layout;
            var newPct = editor_common_1.calcPctFromPx(newWidth, _this.props.lineLength) * 100;
            _this.setState({ resizedPctWidth: newPct });
            var newLayout = _this.calcUnwrappedLayout(newPct, newWidth);
            if (newPct <= 100) {
                if (_this.wrappedLayout && (stop ? newPct !== 100 : true)) {
                    newLayout = layout;
                }
                return {
                    width: newPct,
                    layout: newLayout,
                };
            }
            else {
                return {
                    width: _this.props.pctWidth || null,
                    layout: newLayout,
                };
            }
        };
        _this.calcUnwrappedLayout = function (pct, width) {
            if (pct <= 100) {
                return 'center';
            }
            if (width <= editor_common_1.akEditorWideLayoutWidth) {
                return 'wide';
            }
            return 'full-width';
        };
        _this.calcColumnLeftOffset = function () {
            var offsetLeft = _this.state.offsetLeft;
            return _this.insideInlineLike
                ? editor_common_1.calcColumnsFromPx(offsetLeft, _this.props.lineLength, _this.props.gridSize)
                : 0;
        };
        _this.calcPxWidth = function (useLayout) {
            var _a = _this.props, origWidth = _a.width, origHeight = _a.height, layout = _a.layout, pctWidth = _a.pctWidth, lineLength = _a.lineLength, containerWidth = _a.containerWidth, fullWidthMode = _a.fullWidthMode, getPos = _a.getPos, state = _a.state;
            var resizedPctWidth = _this.state.resizedPctWidth;
            return media_single_1.calcMediaPxWidth({
                origWidth: origWidth,
                origHeight: origHeight,
                pctWidth: pctWidth,
                state: state,
                containerWidth: { width: containerWidth, lineLength: lineLength },
                isFullWidthModeEnabled: fullWidthMode,
                layout: useLayout || layout,
                pos: getPos(),
                resizedPctWidth: resizedPctWidth,
            });
        };
        _this.highlights = function (newWidth, snapPoints) {
            var snapWidth = utils_1.snapTo(newWidth, snapPoints);
            var layoutColumn = _this.props.view.state.schema.nodes.layoutColumn;
            if (_this.$pos &&
                !!prosemirror_utils_1.findParentNodeOfTypeClosestToPos(_this.$pos, [layoutColumn])) {
                return [];
            }
            if (snapWidth > editor_common_1.akEditorWideLayoutWidth) {
                return ['full-width'];
            }
            var _a = _this.props, layout = _a.layout, lineLength = _a.lineLength, gridSize = _a.gridSize;
            var columns = editor_common_1.calcColumnsFromPx(snapWidth, lineLength, gridSize);
            var columnWidth = Math.round(columns);
            var highlight = [];
            if (layout === 'wrap-left' || layout === 'align-start') {
                highlight.push(0, columnWidth);
            }
            else if (layout === 'wrap-right' || layout === 'align-end') {
                highlight.push(gridSize, gridSize - columnWidth);
            }
            else if (_this.insideInlineLike) {
                highlight.push(Math.round(columns + _this.calcColumnLeftOffset()));
            }
            else {
                highlight.push(Math.floor((gridSize - columnWidth) / 2), Math.ceil((gridSize + columnWidth) / 2));
            }
            return highlight;
        };
        return _this;
    }
    ResizableMediaSingle.prototype.componentDidUpdate = function () {
        var offsetLeft = this.calcOffsetLeft();
        if (offsetLeft !== this.state.offsetLeft && offsetLeft >= 0) {
            this.setState({ offsetLeft: offsetLeft });
        }
        return true;
    };
    Object.defineProperty(ResizableMediaSingle.prototype, "wrappedLayout", {
        get: function () {
            return media_single_1.wrappedLayouts.indexOf(this.props.layout) > -1;
        },
        enumerable: true,
        configurable: true
    });
    ResizableMediaSingle.prototype.componentDidMount = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var viewMediaClientConfig;
            return tslib_1.__generator(this, function (_a) {
                viewMediaClientConfig = this.props.viewMediaClientConfig;
                if (viewMediaClientConfig) {
                    this.checkVideoFile(viewMediaClientConfig);
                }
                return [2 /*return*/];
            });
        });
    };
    ResizableMediaSingle.prototype.UNSAFE_componentWillReceiveProps = function (nextProps) {
        if (this.props.viewMediaClientConfig !== nextProps.viewMediaClientConfig) {
            this.checkVideoFile(nextProps.viewMediaClientConfig);
        }
        if (this.props.layout !== nextProps.layout) {
            this.checkLayout(this.props.layout, nextProps.layout);
        }
    };
    ResizableMediaSingle.prototype.checkVideoFile = function (viewMediaClientConfig) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var $pos, mediaNode, mediaClient, state;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        $pos = this.$pos;
                        if (!$pos || !viewMediaClientConfig) {
                            return [2 /*return*/];
                        }
                        mediaNode = this.props.state.doc.nodeAt($pos.pos + 1);
                        if (!mediaNode) {
                            return [2 /*return*/];
                        }
                        mediaClient = media_client_1.getMediaClient({
                            mediaClientConfig: viewMediaClientConfig,
                        });
                        return [4 /*yield*/, mediaClient.file.getCurrentState(mediaNode.attrs.id, {
                                collectionName: mediaNode.attrs.collection,
                            })];
                    case 1:
                        state = _a.sent();
                        if (state && state.status !== 'error' && state.mediaType === 'image') {
                            this.setState({
                                isVideoFile: false,
                            });
                        }
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * When returning to center layout from a wrapped/aligned layout, it might actually
     * be wide or full-width
     */
    ResizableMediaSingle.prototype.checkLayout = function (oldLayout, newLayout) {
        var resizedPctWidth = this.state.resizedPctWidth;
        if (media_single_1.wrappedLayouts.indexOf(oldLayout) > -1 &&
            newLayout === 'center' &&
            resizedPctWidth) {
            var layout = this.calcUnwrappedLayout(resizedPctWidth, this.calcPxWidth(newLayout));
            this.props.updateSize(resizedPctWidth, layout);
        }
    };
    Object.defineProperty(ResizableMediaSingle.prototype, "$pos", {
        get: function () {
            var pos = this.props.getPos();
            if (Number.isNaN(pos) || typeof pos !== 'number') {
                return null;
            }
            // need to pass view because we may not get updated props in time
            return this.props.view.state.doc.resolve(pos);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResizableMediaSingle.prototype, "gridWidth", {
        /**
         * The maxmimum number of grid columns this node can resize to.
         */
        get: function () {
            var gridSize = this.props.gridSize;
            return !(this.wrappedLayout || this.insideInlineLike)
                ? gridSize / 2
                : gridSize;
        },
        enumerable: true,
        configurable: true
    });
    ResizableMediaSingle.prototype.calcOffsetLeft = function () {
        var offsetLeft = 0;
        if (this.wrapper && this.insideInlineLike) {
            var currentNode = this.wrapper;
            var boundingRect = currentNode.getBoundingClientRect();
            var pmRect = this.props.view.dom.getBoundingClientRect();
            offsetLeft = boundingRect.left - pmRect.left;
        }
        return offsetLeft;
    };
    ResizableMediaSingle.prototype.calcSnapPoints = function () {
        var offsetLeft = this.state.offsetLeft;
        var _a = this.props, containerWidth = _a.containerWidth, lineLength = _a.lineLength, allowBreakoutSnapPoints = _a.allowBreakoutSnapPoints;
        var snapTargets = [];
        for (var i = 0; i < this.gridWidth; i++) {
            snapTargets.push(editor_common_1.calcPxFromColumns(i, lineLength, this.gridWidth) - offsetLeft);
        }
        // full width
        snapTargets.push(lineLength - offsetLeft);
        var minimumWidth = editor_common_1.calcPxFromColumns(this.wrappedLayout || this.insideInlineLike ? 1 : 2, lineLength, this.props.gridSize);
        var snapPoints = snapTargets.filter(function (width) { return width >= minimumWidth; });
        var $pos = this.$pos;
        if (!$pos) {
            return snapPoints;
        }
        var isVideoFile = this.state.isVideoFile;
        snapPoints = isVideoFile
            ? snapPoints.filter(function (width) { return width > 320; })
            : snapPoints;
        var isTopLevel = $pos.parent.type.name === 'doc';
        if (isTopLevel && allowBreakoutSnapPoints) {
            snapPoints.push(editor_common_1.akEditorWideLayoutWidth);
            var fullWidthPoint = containerWidth - editor_common_1.akEditorBreakoutPadding;
            if (fullWidthPoint > editor_common_1.akEditorWideLayoutWidth) {
                snapPoints.push(fullWidthPoint);
            }
        }
        return snapPoints;
    };
    Object.defineProperty(ResizableMediaSingle.prototype, "insideInlineLike", {
        get: function () {
            var $pos = this.$pos;
            if (!$pos) {
                return false;
            }
            var _a = this.props.view.state.schema.nodes, table = _a.table, listItem = _a.listItem;
            return !!prosemirror_utils_1.findParentNodeOfTypeClosestToPos($pos, [table, listItem]);
        },
        enumerable: true,
        configurable: true
    });
    ResizableMediaSingle.prototype.render = function () {
        var _this = this;
        var _a = this.props, origWidth = _a.width, origHeight = _a.height, layout = _a.layout, pctWidth = _a.pctWidth, containerWidth = _a.containerWidth, fullWidthMode = _a.fullWidthMode;
        var pxWidth = this.calcPxWidth();
        // scale, keeping aspect ratio
        var height = (origHeight / origWidth) * pxWidth;
        var width = pxWidth;
        var enable = {};
        utils_1.handleSides.forEach(function (side) {
            var oppositeSide = side === 'left' ? 'right' : 'left';
            enable[side] =
                ['full-width', 'wide', 'center']
                    .concat("wrap-" + oppositeSide)
                    .concat("align-" + utils_1.imageAlignmentMap[oppositeSide])
                    .indexOf(layout) > -1;
            if (side === 'left' && _this.insideInlineLike) {
                enable[side] = false;
            }
        });
        return (React.createElement(styled_1.Wrapper, { width: width, height: height, layout: layout, isResized: !!pctWidth, containerWidth: containerWidth || origWidth, innerRef: function (elem) { return (_this.wrapper = elem); }, fullWidthMode: fullWidthMode },
            React.createElement(Resizer_1.default, tslib_1.__assign({}, this.props, { width: width, height: height, selected: this.props.selected, enable: enable, calcNewSize: this.calcNewSize, snapPoints: this.calcSnapPoints(), scaleFactor: !this.wrappedLayout && !this.insideInlineLike ? 2 : 1, highlights: this.highlights }), this.props.children)));
    };
    return ResizableMediaSingle;
}(React.Component));
exports.default = ResizableMediaSingle;
//# sourceMappingURL=index.js.map