"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var prosemirror_state_1 = require("prosemirror-state");
var prosemirror_utils_1 = require("prosemirror-utils");
var utils_1 = require("../utils");
var types_1 = require("../types");
var main_1 = require("../pm-plugins/main");
var prosemirror_tables_1 = require("prosemirror-tables");
exports.sortByColumn = function (columnIndex, order) {
    if (order === void 0) { order = types_1.SortOrder.DESC; }
    return function (state, dispatch) {
        var tr = state.tr;
        var table = prosemirror_utils_1.findTable(tr.selection);
        if (!table || !table.node) {
            return false;
        }
        var selectionRect = prosemirror_utils_1.isCellSelection(tr.selection)
            ? prosemirror_utils_1.getSelectionRect(tr.selection)
            : prosemirror_utils_1.findCellRectClosestToPos(tr.selection.$from);
        if (!selectionRect) {
            return false;
        }
        var tablePluginState = main_1.getPluginState(state);
        var tableArray = prosemirror_utils_1.convertTableNodeToArrayOfRows(table.node);
        var headerRow;
        if (tablePluginState.isHeaderRowEnabled) {
            headerRow = tableArray.shift();
        }
        var sortedTable = tableArray.sort(function (rowA, rowB) {
            return (order === types_1.SortOrder.DESC ? -1 : 1) *
                utils_1.compareNodes(rowA[columnIndex], rowB[columnIndex]);
        });
        if (headerRow) {
            sortedTable.unshift(headerRow);
        }
        var newTableNode = prosemirror_utils_1.convertArrayOfRowsToTableNode(table.node, sortedTable);
        tr.replaceWith(table.pos, table.pos + table.node.nodeSize, newTableNode);
        if (dispatch) {
            var pos = prosemirror_tables_1.TableMap.get(table.node).positionAt(selectionRect.top, columnIndex, table.node);
            dispatch(tr.setSelection(prosemirror_state_1.Selection.near(tr.doc.resolve(table.start + pos))));
        }
        return true;
    };
};
//# sourceMappingURL=sort.js.map